@@ -11,13 +11,13 @@ unless (@ARGV > 0) {
 my ($gpib,$goto)=@ARGV;
 
 my $source=new Lab::Instrument::Yokogawa7651(
-        connection_type=>'LinuxGPIB',
+        connection_type=>'VISA_GPIB',
         gpib_address => $gpib,
         gpib_board=>0,
 	gate_protect=>1,
-	gp_max_volt_per_second=>0.05,
+	gp_max_units_per_second=>0.05,
 	gp_max_step_per_second=>10,
-	gp_max_volt_per_step=>0.005
+	gp_max_units_per_step=>0.005
 );
 
 if (defined $goto) {
