@@ -1,20 +1,21 @@
 #!/usr/bin/perl -w
 
 package Lab::Bus;
-our $VERSION = '3.31';
+our $VERSION = '3.32';
 
 use strict;
 
+use Lab::Generic;
 use Lab::Exception;
 use Time::HiRes qw (usleep sleep);
-use POSIX; # added for int() function
+#use POSIX; # added for int() function
 use Scalar::Util qw(weaken);
 use Carp qw(croak cluck);
 use Data::Dumper;
 our $AUTOLOAD;
 
 
-our @ISA = ();
+our @ISA = ('Lab::Generic');
 
 
 # this holds a list of references to all the bus objects that are floating around in memory,
@@ -40,7 +41,7 @@ sub new {
 	my $config = undef;
 	if (ref $_[0] eq 'HASH') { $config=shift } # try to be flexible about options as hash/hashref
 	else { $config={@_} }
-	my $self={};
+	my $self=$class->SUPER::new(@_);
 	bless ($self, $class);
 	$self->${\(__PACKAGE__.'::_construct')}(__PACKAGE__);
 
