@@ -2,7 +2,7 @@ package Lab::Instrument::Source;
 use strict;
 use warnings;
 
-our $VERSION = '3.31';
+our $VERSION = '3.32';
 
 use Lab::Exception;
 use Lab::Instrument;
@@ -32,7 +32,7 @@ our %fields = (
 		fast_set => undef,
 		autorange => 0, 	# silently ignored by instruments (or drivers) which don't support autorange
 		
-		read_default => 'cache'
+		read_default => 'device'
 	},
 
 	# Config hash passed to subchannel objects, or to $self->configure()
